==> Microsoft-AdCenter-8.00_01.tar.gz: Microsoft-AdCenter-8.00/lib/Microsoft/AdCenter/V6/CustomerManagementService/CountryCode.pm <==
package Microsoft::AdCenter::V6::CustomerManagementService::CountryCode;
# Copyright (C) 2011 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

sub AD {
    return 'AD';
}

sub AE {
    return 'AE';
}

sub AF {
    return 'AF';
}

sub AG {
    return 'AG';
}

sub AI {
    return 'AI';
}

sub AL {
    return 'AL';
}

sub AM {
    return 'AM';
}

sub AN {
    return 'AN';
}

sub AO {
    return 'AO';
}

sub AQ {
    return 'AQ';
}

sub AR {
    return 'AR';
}

sub AS {
    return 'AS';
}

sub AT {
    return 'AT';
}

sub AU {
    return 'AU';
}

sub AW {
    return 'AW';
}

sub AZ {
    return 'AZ';
}

sub BA {
    return 'BA';
}

sub BB {
    return 'BB';
}

sub BD {
    return 'BD';
}

sub BE {
    return 'BE';
}

sub BF {
    return 'BF';
}

sub BG {
    return 'BG';
}

sub BH {
    return 'BH';
}

sub BI {
    return 'BI';
}

sub BJ {
    return 'BJ';
}

sub BM {
    return 'BM';
}

sub BN {
    return 'BN';
}

sub BO {
    return 'BO';
}

sub BR {
    return 'BR';
}

sub BS {
    return 'BS';
}

sub BT {
    return 'BT';
}

sub BV {
    return 'BV';
}

sub BW {
    return 'BW';
}

sub BY {
    return 'BY';
}

sub BZ {
    return 'BZ';
}

sub CA {
    return 'CA';
}

sub CC {
    return 'CC';
}

sub CD {
    return 'CD';
}

sub CF {
    return 'CF';
}

sub CG {
    return 'CG';
}

sub CH {
    return 'CH';
}

sub CI {
    return 'CI';
}

sub CK {
    return 'CK';
}

sub CL {
    return 'CL';
}

sub CM {
    return 'CM';
}

sub CN {
    return 'CN';
}

sub CO {
    return 'CO';
}

sub CR {
    return 'CR';
}

sub CS {
    return 'CS';
}

sub CU {
    return 'CU';
}

sub CV {
    return 'CV';
}

sub CX {
    return 'CX';
}

sub CY {
    return 'CY';
}

sub CZ {
    return 'CZ';
}

sub DE {
    return 'DE';
}

sub DJ {
    return 'DJ';
}

sub DK {
    return 'DK';
}

sub DM {
    return 'DM';
}

sub DO {
    return 'DO';
}

sub DZ {
    return 'DZ';
}

sub EC {
    return 'EC';
}

sub EE {
    return 'EE';
}

sub EG {
    return 'EG';
}

sub ER {
    return 'ER';
}

sub ES {
    return 'ES';
}

sub ET {
    return 'ET';
}

sub FI {
    return 'FI';
}

sub FJ {
    return 'FJ';
}

sub FK {
    return 'FK';
}

sub FM {
    return 'FM';
}

sub FO {
    return 'FO';
}

sub FR {
    return 'FR';
}

sub GA {
    return 'GA';
}

sub GB {
    return 'GB';
}

sub GD {
    return 'GD';
}

sub GE {
    return 'GE';
}

sub GF {
    return 'GF';
}

sub GH {
    return 'GH';
}

sub GI {
    return 'GI';
}

sub GL {
    return 'GL';
}

sub GM {
    return 'GM';
}

sub GN {
    return 'GN';
}

sub GP {
    return 'GP';
}

sub GQ {
    return 'GQ';
}

sub GR {
    return 'GR';
}

sub GS {
    return 'GS';
}

sub GT {
    return 'GT';
}

sub GU {
    return 'GU';
}

sub GW {
    return 'GW';
}

sub GY {
    return 'GY';
}

sub HK {
    return 'HK';
}

sub HM {
    return 'HM';
}

sub HN {
    return 'HN';
}

sub HR {
    return 'HR';
}

sub HT {
    return 'HT';
}

sub HU {
    return 'HU';
}

sub ID {
    return 'ID';
}

sub IE {
    return 'IE';
}

sub IL {
    return 'IL';
}

sub IN {
    return 'IN';
}

sub IO {
    return 'IO';
}

sub IQ {
    return 'IQ';
}

sub IR {
    return 'IR';
}

sub IS {
    return 'IS';
}

sub IT {
    return 'IT';
}

sub JM {
    return 'JM';
}

sub JO {
    return 'JO';
}

sub JP {
    return 'JP';
}

sub KE {
    return 'KE';
}

sub KG {
    return 'KG';
}

sub KH {
    return 'KH';
}

sub KI {
    return 'KI';
}

sub KM {
    return 'KM';
}

sub KN {
    return 'KN';
}

sub KP {
    return 'KP';
}

sub KR {
    return 'KR';
}

sub KW {
    return 'KW';
}

sub KY {
    return 'KY';
}

sub KZ {
    return 'KZ';
}

sub LA {
    return 'LA';
}

sub LB {
    return 'LB';
}

sub LC {
    return 'LC';
}

sub LI {
    return 'LI';
}

sub LK {
    return 'LK';
}

sub LR {
    return 'LR';
}

sub LS {
    return 'LS';
}

sub LT {
    return 'LT';
}

sub LU {
    return 'LU';
}

sub LV {
    return 'LV';
}

sub LY {
    return 'LY';
}

sub MA {
    return 'MA';
}

sub MC {
    return 'MC';
}

sub MD {
    return 'MD';
}

sub MG {
    return 'MG';
}

sub MH {
    return 'MH';
}

sub MK {
    return 'MK';
}

sub ML {
    return 'ML';
}

sub MM {
    return 'MM';
}

sub MN {
    return 'MN';
}

sub MO {
    return 'MO';
}

sub MP {
    return 'MP';
}

sub MQ {
    return 'MQ';
}

sub MR {
    return 'MR';
}

sub MS {
    return 'MS';
}

sub MT {
    return 'MT';
}

sub MU {
    return 'MU';
}

sub MV {
    return 'MV';
}

sub MW {
    return 'MW';
}

sub MX {
    return 'MX';
}

sub MY {
    return 'MY';
}

sub MZ {
    return 'MZ';
}

sub NA {
    return 'NA';
}

sub NC {
    return 'NC';
}

sub NE {
    return 'NE';
}

sub NF {
    return 'NF';
}

sub NG {
    return 'NG';
}

sub NI {
    return 'NI';
}

sub NL {
    return 'NL';
}

sub NO {
    return 'NO';
}

sub NP {
    return 'NP';
}

sub NR {
    return 'NR';
}

sub NU {
    return 'NU';
}

sub NZ {
    return 'NZ';
}

sub OM {
    return 'OM';
}

sub PA {
    return 'PA';
}

sub PE {
    return 'PE';
}

sub PF {
    return 'PF';
}

sub PG {
    return 'PG';
}

sub PH {
    return 'PH';
}

sub PK {
    return 'PK';
}

sub PL {
    return 'PL';
}

sub PM {
    return 'PM';
}

sub PN {
    return 'PN';
}

sub PR {
    return 'PR';
}

sub PS {
    return 'PS';
}

sub PT {
    return 'PT';
}

sub PW {
    return 'PW';
}

sub PY {
    return 'PY';
}

sub QA {
    return 'QA';
}

sub RE {
    return 'RE';
}

sub RO {
    return 'RO';
}

sub RU {
    return 'RU';
}

sub RW {
    return 'RW';
}

sub SA {
    return 'SA';
}

sub SB {
    return 'SB';
}

sub SC {
    return 'SC';
}

sub SD {
    return 'SD';
}

sub SE {
    return 'SE';
}

sub SG {
    return 'SG';
}

sub SH {
    return 'SH';
}

sub SI {
    return 'SI';
}

sub SJ {
    return 'SJ';
}

sub SK {
    return 'SK';
}

sub SL {
    return 'SL';
}

sub SM {
    return 'SM';
}

sub SN {
    return 'SN';
}

sub SO {
    return 'SO';
}

sub SR {
    return 'SR';
}

sub ST {
    return 'ST';
}

sub SV {
    return 'SV';
}

sub SY {
    return 'SY';
}

sub SZ {
    return 'SZ';
}

sub TC {
    return 'TC';
}

sub TD {
    return 'TD';
}

sub TF {
    return 'TF';
}

sub TG {
    return 'TG';
}

sub TH {
    return 'TH';
}

sub TJ {
    return 'TJ';
}

sub TK {
    return 'TK';
}

sub TL {
    return 'TL';
}

sub TM {
    return 'TM';
}

sub TN {
    return 'TN';
}

sub TO {
    return 'TO';
}

sub TR {
    return 'TR';
}

sub TT {
    return 'TT';
}

sub TV {
    return 'TV';
}

sub TW {
    return 'TW';
}

sub TZ {
    return 'TZ';
}

sub UA {
    return 'UA';
}

sub UG {
    return 'UG';
}

sub UM {
    return 'UM';
}

sub UNDEFINED {
    return 'UNDEFINED';
}

sub US {
    return 'US';
}

sub UY {
    return 'UY';
}

sub UZ {
    return 'UZ';
}

sub VA {
    return 'VA';
}

sub VC {
    return 'VC';
}

sub VE {
    return 'VE';
}

sub VG {
    return 'VG';
}

sub VI {
    return 'VI';
}

sub VN {
    return 'VN';
}

sub VU {
    return 'VU';
}

sub WF {
    return 'WF';
}

sub WS {
    return 'WS';
}

sub YE {
    return 'YE';
}

sub YT {
    return 'YT';
}

sub ZA {
    return 'ZA';
}

sub ZM {
    return 'ZM';
}

sub ZW {
    return 'ZW';
}

1;

==> Microsoft-AdCenter-8.00_02.tar.gz: Microsoft-AdCenter-8.00/lib/Microsoft/AdCenter/V6/CustomerManagementService/CountryCode.pm <==
package Microsoft::AdCenter::V6::CustomerManagementService::CountryCode;
# Copyright (C) 2011 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

=head1 NAME

Microsoft::AdCenter::V6::CustomerManagementService::CountryCode - Represents "CountryCode" in Microsoft AdCenter Customer Management Service.

=head1 SYNOPSIS

See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.

=head1 ENUMERATION VALUES

AD
AE
AF
AG
AI
AL
AM
AN
AO
AQ
AR
AS
AT
AU
AW
AZ
BA
BB
BD
BE
BF
BG
BH
BI
BJ
BM
BN
BO
BR
BS
BT
BV
BW
BY
BZ
CA
CC
CD
CF
CG
CH
CI
CK
CL
CM
CN
CO
CR
CS
CU
CV
CX
CY
CZ
DE
DJ
DK
DM
DO
DZ
EC
EE
EG
ER
ES
ET
FI
FJ
FK
FM
FO
FR
GA
GB
GD
GE
GF
GH
GI
GL
GM
GN
GP
GQ
GR
GS
GT
GU
GW
GY
HK
HM
HN
HR
HT
HU
ID
IE
IL
IN
IO
IQ
IR
IS
IT
JM
JO
JP
KE
KG
KH
KI
KM
KN
KP
KR
KW
KY
KZ
LA
LB
LC
LI
LK
LR
LS
LT
LU
LV
LY
MA
MC
MD
MG
MH
MK
ML
MM
MN
MO
MP
MQ
MR
MS
MT
MU
MV
MW
MX
MY
MZ
NA
NC
NE
NF
NG
NI
NL
NO
NP
NR
NU
NZ
OM
PA
PE
PF
PG
PH
PK
PL
PM
PN
PR
PS
PT
PW
PY
QA
RE
RO
RU
RW
SA
SB
SC
SD
SE
SG
SH
SI
SJ
SK
SL
SM
SN
SO
SR
ST
SV
SY
SZ
TC
TD
TF
TG
TH
TJ
TK
TL
TM
TN
TO
TR
TT
TV
TW
TZ
UA
UG
UM
UNDEFINED
US
UY
UZ
VA
VC
VE
VG
VI
VN
VU
WF
WS
YE
YT
ZA
ZM
ZW

=cut

sub AD {
    return 'AD';
}

sub AE {
    return 'AE';
}

sub AF {
    return 'AF';
}

sub AG {
    return 'AG';
}

sub AI {
    return 'AI';
}

sub AL {
    return 'AL';
}

sub AM {
    return 'AM';
}

sub AN {
    return 'AN';
}

sub AO {
    return 'AO';
}

sub AQ {
    return 'AQ';
}

sub AR {
    return 'AR';
}

sub AS {
    return 'AS';
}

sub AT {
    return 'AT';
}

sub AU {
    return 'AU';
}

sub AW {
    return 'AW';
}

sub AZ {
    return 'AZ';
}

sub BA {
    return 'BA';
}

sub BB {
    return 'BB';
}

sub BD {
    return 'BD';
}

sub BE {
    return 'BE';
}

sub BF {
    return 'BF';
}

sub BG {
    return 'BG';
}

sub BH {
    return 'BH';
}

sub BI {
    return 'BI';
}

sub BJ {
    return 'BJ';
}

sub BM {
    return 'BM';
}

sub BN {
    return 'BN';
}

sub BO {
    return 'BO';
}

sub BR {
    return 'BR';
}

sub BS {
    return 'BS';
}

sub BT {
    return 'BT';
}

sub BV {
    return 'BV';
}

sub BW {
    return 'BW';
}

sub BY {
    return 'BY';
}

sub BZ {
    return 'BZ';
}

sub CA {
    return 'CA';
}

sub CC {
    return 'CC';
}

sub CD {
    return 'CD';
}

sub CF {
    return 'CF';
}

sub CG {
    return 'CG';
}

sub CH {
    return 'CH';
}

sub CI {
    return 'CI';
}

sub CK {
    return 'CK';
}

sub CL {
    return 'CL';
}

sub CM {
    return 'CM';
}

sub CN {
    return 'CN';
}

sub CO {
    return 'CO';
}

sub CR {
    return 'CR';
}

sub CS {
    return 'CS';
}

sub CU {
    return 'CU';
}

sub CV {
    return 'CV';
}

sub CX {
    return 'CX';
}

sub CY {
    return 'CY';
}

sub CZ {
    return 'CZ';
}

sub DE {
    return 'DE';
}

sub DJ {
    return 'DJ';
}

sub DK {
    return 'DK';
}

sub DM {
    return 'DM';
}

sub DO {
    return 'DO';
}

sub DZ {
    return 'DZ';
}

sub EC {
    return 'EC';
}

sub EE {
    return 'EE';
}

sub EG {
    return 'EG';
}

sub ER {
    return 'ER';
}

sub ES {
    return 'ES';
}

sub ET {
    return 'ET';
}

sub FI {
    return 'FI';
}

sub FJ {
    return 'FJ';
}

sub FK {
    return 'FK';
}

sub FM {
    return 'FM';
}

sub FO {
    return 'FO';
}

sub FR {
    return 'FR';
}

sub GA {
    return 'GA';
}

sub GB {
    return 'GB';
}

sub GD {
    return 'GD';
}

sub GE {
    return 'GE';
}

sub GF {
    return 'GF';
}

sub GH {
    return 'GH';
}

sub GI {
    return 'GI';
}

sub GL {
    return 'GL';
}

sub GM {
    return 'GM';
}

sub GN {
    return 'GN';
}

sub GP {
    return 'GP';
}

sub GQ {
    return 'GQ';
}

sub GR {
    return 'GR';
}

sub GS {
    return 'GS';
}

sub GT {
    return 'GT';
}

sub GU {
    return 'GU';
}

sub GW {
    return 'GW';
}

sub GY {
    return 'GY';
}

sub HK {
    return 'HK';
}

sub HM {
    return 'HM';
}

sub HN {
    return 'HN';
}

sub HR {
    return 'HR';
}

sub HT {
    return 'HT';
}

sub HU {
    return 'HU';
}

sub ID {
    return 'ID';
}

sub IE {
    return 'IE';
}

sub IL {
    return 'IL';
}

sub IN {
    return 'IN';
}

sub IO {
    return 'IO';
}

sub IQ {
    return 'IQ';
}

sub IR {
    return 'IR';
}

sub IS {
    return 'IS';
}

sub IT {
    return 'IT';
}

sub JM {
    return 'JM';
}

sub JO {
    return 'JO';
}

sub JP {
    return 'JP';
}

sub KE {
    return 'KE';
}

sub KG {
    return 'KG';
}

sub KH {
    return 'KH';
}

sub KI {
    return 'KI';
}

sub KM {
    return 'KM';
}

sub KN {
    return 'KN';
}

sub KP {
    return 'KP';
}

sub KR {
    return 'KR';
}

sub KW {
    return 'KW';
}

sub KY {
    return 'KY';
}

sub KZ {
    return 'KZ';
}

sub LA {
    return 'LA';
}

sub LB {
    return 'LB';
}

sub LC {
    return 'LC';
}

sub LI {
    return 'LI';
}

sub LK {
    return 'LK';
}

sub LR {
    return 'LR';
}

sub LS {
    return 'LS';
}

sub LT {
    return 'LT';
}

sub LU {
    return 'LU';
}

sub LV {
    return 'LV';
}

sub LY {
    return 'LY';
}

sub MA {
    return 'MA';
}

sub MC {
    return 'MC';
}

sub MD {
    return 'MD';
}

sub MG {
    return 'MG';
}

sub MH {
    return 'MH';
}

sub MK {
    return 'MK';
}

sub ML {
    return 'ML';
}

sub MM {
    return 'MM';
}

sub MN {
    return 'MN';
}

sub MO {
    return 'MO';
}

sub MP {
    return 'MP';
}

sub MQ {
    return 'MQ';
}

sub MR {
    return 'MR';
}

sub MS {
    return 'MS';
}

sub MT {
    return 'MT';
}

sub MU {
    return 'MU';
}

sub MV {
    return 'MV';
}

sub MW {
    return 'MW';
}

sub MX {
    return 'MX';
}

sub MY {
    return 'MY';
}

sub MZ {
    return 'MZ';
}

sub NA {
    return 'NA';
}

sub NC {
    return 'NC';
}

sub NE {
    return 'NE';
}

sub NF {
    return 'NF';
}

sub NG {
    return 'NG';
}

sub NI {
    return 'NI';
}

sub NL {
    return 'NL';
}

sub NO {
    return 'NO';
}

sub NP {
    return 'NP';
}

sub NR {
    return 'NR';
}

sub NU {
    return 'NU';
}

sub NZ {
    return 'NZ';
}

sub OM {
    return 'OM';
}

sub PA {
    return 'PA';
}

sub PE {
    return 'PE';
}

sub PF {
    return 'PF';
}

sub PG {
    return 'PG';
}

sub PH {
    return 'PH';
}

sub PK {
    return 'PK';
}

sub PL {
    return 'PL';
}

sub PM {
    return 'PM';
}

sub PN {
    return 'PN';
}

sub PR {
    return 'PR';
}

sub PS {
    return 'PS';
}

sub PT {
    return 'PT';
}

sub PW {
    return 'PW';
}

sub PY {
    return 'PY';
}

sub QA {
    return 'QA';
}

sub RE {
    return 'RE';
}

sub RO {
    return 'RO';
}

sub RU {
    return 'RU';
}

sub RW {
    return 'RW';
}

sub SA {
    return 'SA';
}

sub SB {
    return 'SB';
}

sub SC {
    return 'SC';
}

sub SD {
    return 'SD';
}

sub SE {
    return 'SE';
}

sub SG {
    return 'SG';
}

sub SH {
    return 'SH';
}

sub SI {
    return 'SI';
}

sub SJ {
    return 'SJ';
}

sub SK {
    return 'SK';
}

sub SL {
    return 'SL';
}

sub SM {
    return 'SM';
}

sub SN {
    return 'SN';
}

sub SO {
    return 'SO';
}

sub SR {
    return 'SR';
}

sub ST {
    return 'ST';
}

sub SV {
    return 'SV';
}

sub SY {
    return 'SY';
}

sub SZ {
    return 'SZ';
}

sub TC {
    return 'TC';
}

sub TD {
    return 'TD';
}

sub TF {
    return 'TF';
}

sub TG {
    return 'TG';
}

sub TH {
    return 'TH';
}

sub TJ {
    return 'TJ';
}

sub TK {
    return 'TK';
}

sub TL {
    return 'TL';
}

sub TM {
    return 'TM';
}

sub TN {
    return 'TN';
}

sub TO {
    return 'TO';
}

sub TR {
    return 'TR';
}

sub TT {
    return 'TT';
}

sub TV {
    return 'TV';
}

sub TW {
    return 'TW';
}

sub TZ {
    return 'TZ';
}

sub UA {
    return 'UA';
}

sub UG {
    return 'UG';
}

sub UM {
    return 'UM';
}

sub UNDEFINED {
    return 'UNDEFINED';
}

sub US {
    return 'US';
}

sub UY {
    return 'UY';
}

sub UZ {
    return 'UZ';
}

sub VA {
    return 'VA';
}

sub VC {
    return 'VC';
}

sub VE {
    return 'VE';
}

sub VG {
    return 'VG';
}

sub VI {
    return 'VI';
}

sub VN {
    return 'VN';
}

sub VU {
    return 'VU';
}

sub WF {
    return 'WF';
}

sub WS {
    return 'WS';
}

sub YE {
    return 'YE';
}

sub YT {
    return 'YT';
}

sub ZA {
    return 'ZA';
}

sub ZM {
    return 'ZM';
}

sub ZW {
    return 'ZW';
}

1;
